@@ -17,24 +17,51 @@
 // under the License.
 // </copyright>
 
-using System.Threading.Tasks;
+using System;
+using System.Text;
+using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.WebExtension;
 
-public sealed class Extension
+public sealed record Extension
 {
-    private readonly BiDi _bidi;
-
     public Extension(BiDi bidi, string id)
+        : this(id)
+    {
+        BiDi = bidi ?? throw new ArgumentNullException(nameof(bidi));
+    }
+
+    [JsonConstructor]
+    internal Extension(string id)
     {
-        _bidi = bidi;
         Id = id;
     }
 
     internal string Id { get; }
 
-    public Task UninstallAsync(UninstallOptions? options = null)
+    private BiDi? _bidi;
+
+    [JsonIgnore]
+    public BiDi BiDi
     {
-        return _bidi.WebExtension.UninstallAsync(this, options);
+        get => _bidi ?? throw new InvalidOperationException($"{nameof(BiDi)} instance has not been hydrated.");
+        internal set => _bidi = value;
+    }
+
+    public bool Equals(Extension? other)
+    {
+        return other is not null && string.Equals(Id, other.Id, StringComparison.Ordinal);
+    }
+
+    public override int GetHashCode()
+    {
+        return Id is not null ? StringComparer.Ordinal.GetHashCode(Id) : 0;
+    }
+
+    // Includes Id only for brevity
+    private bool PrintMembers(StringBuilder builder)
+    {
+        builder.Append($"Id = {Id}");
+        return true;
     }
 }
