@@ -376,7 +376,7 @@ public class CookieImplementationTest : DriverTestFixture
         count = driver.Manage().Cookies.AllCookies.Count;
 
         driver.Url = grandchildPage;
-        Cookie cookie3 = new Cookie("dog", "dalmation", "/" + basePath + "/child/grandchild/");
+        Cookie cookie3 = new Cookie("dog", "dalmatian", "/" + basePath + "/child/grandchild/");
         driver.Manage().Cookies.AddCookie(cookie3);
         count = driver.Manage().Cookies.AllCookies.Count;
 
@@ -912,7 +912,7 @@ public class CookieImplementationTest : DriverTestFixture
     {
         // TODO(JimEvan): Some coverage is better than none, so we
         // need to ignore the fact that localhost cookies are problematic.
-        // Reenable this when we have a better solution per DanielWagnerHall.
+        // Re-enable this when we have a better solution per DanielWagnerHall.
         // ChromeDriver2 has trouble with localhost. IE and Firefox don't.
         // return !IsIpv4Address(hostname) && "localhost" != hostname;
         bool isLocalHostOkay = !("localhost" == hostname && !TestUtilities.IsInternetExplorer(driver));
