@@ -19,25 +19,24 @@
 
 using NUnit.Framework;
 
-namespace OpenQA.Selenium.Support.Events
+namespace OpenQA.Selenium.Support.Events;
+
+[TestFixture]
+public class EventFiringWebDriverElementTest : DriverTestFixture
 {
-    [TestFixture]
-    public class EventFiringWebDriverElementTest : DriverTestFixture
+    [SetUp]
+    public void Setup()
     {
-        [SetUp]
-        public void Setup()
-        {
-            driver.Url = formsPage;
-        }
+        driver.Url = formsPage;
+    }
 
-        [Test]
-        public void CanTakeEventFiringWebElementScreenshot()
-        {
-            var firingDriver = new EventFiringWebDriver(driver);
-            IWebElement element = firingDriver.FindElement(By.Name("checky"));
-            Screenshot screenshot = ((ITakesScreenshot)element).GetScreenshot();
+    [Test]
+    public void CanTakeEventFiringWebElementScreenshot()
+    {
+        var firingDriver = new EventFiringWebDriver(driver);
+        IWebElement element = firingDriver.FindElement(By.Name("checky"));
+        Screenshot screenshot = ((ITakesScreenshot)element).GetScreenshot();
 
-            Assert.That(screenshot, Is.Not.Null);
-        }
+        Assert.That(screenshot, Is.Not.Null);
     }
 }
