@@ -17,23 +17,27 @@
 
 package org.openqa.selenium;
 
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
+
 /**
  * Thrown when a driver fails to set a cookie.
  *
  * @see org.openqa.selenium.WebDriver.Options#addCookie(Cookie)
  */
+@NullMarked
 public class UnableToSetCookieException extends WebDriverException {
   public UnableToSetCookieException() {}
 
-  public UnableToSetCookieException(String message) {
+  public UnableToSetCookieException(@Nullable String message) {
     super(message);
   }
 
-  public UnableToSetCookieException(Throwable cause) {
+  public UnableToSetCookieException(@Nullable Throwable cause) {
     super(cause);
   }
 
-  public UnableToSetCookieException(String message, Throwable cause) {
+  public UnableToSetCookieException(@Nullable String message, @Nullable Throwable cause) {
     super(message, cause);
   }
 }
