@@ -39,6 +39,6 @@ public class StorageKeyPartitionDescriptor extends PartitionDescriptor {
   }
 
   public Map<String, Object> toMap() {
-    return map;
+    return Map.copyOf(map);
   }
 }
