@@ -20,7 +20,10 @@ package org.openqa.selenium.grid.sessionmap.local;
 import static org.openqa.selenium.remote.RemoteTags.SESSION_ID;
 import static org.openqa.selenium.remote.RemoteTags.SESSION_ID_EVENT;
 
+import com.github.benmanes.caffeine.cache.Cache;
+import com.github.benmanes.caffeine.cache.Caffeine;
 import java.net.URI;
+import java.time.Duration;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.HashMap;
@@ -31,13 +34,14 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import java.util.logging.Logger;
 import org.openqa.selenium.NoSuchSessionException;
-import org.openqa.selenium.events.Event;
 import org.openqa.selenium.events.EventBus;
 import org.openqa.selenium.grid.config.Config;
 import org.openqa.selenium.grid.data.NodeRemovedEvent;
 import org.openqa.selenium.grid.data.NodeRestartedEvent;
 import org.openqa.selenium.grid.data.Session;
 import org.openqa.selenium.grid.data.SessionClosedEvent;
+import org.openqa.selenium.grid.data.SessionClosedReason;
+import org.openqa.selenium.grid.data.SessionRemovalInfo;
 import org.openqa.selenium.grid.log.LoggingOptions;
 import org.openqa.selenium.grid.server.EventBusOptions;
 import org.openqa.selenium.grid.sessionmap.SessionMap;
@@ -55,23 +59,34 @@ public class LocalSessionMap extends SessionMap {
   private final EventBus bus;
   private final IndexedSessionMap knownSessions = new IndexedSessionMap();
 
+  /**
+   * Tracks removed sessions with their removal reason and timestamp for 60 minutes to provide
+   * better diagnostics when a NoSuchSessionException occurs.
+   */
+  private final Cache<SessionId, SessionRemovalInfo> recentlyRemovedSessions =
+      Caffeine.newBuilder().expireAfterWrite(Duration.ofMinutes(60)).build();
+
   public LocalSessionMap(Tracer tracer, EventBus bus) {
     super(tracer);
 
     this.bus = Require.nonNull("Event bus", bus);
 
-    bus.addListener(SessionClosedEvent.listener(this::remove));
+    // Listen to SessionClosedEvent and extract both sessionId and reason
+    bus.addListener(
+        SessionClosedEvent.listener(
+            data -> removeWithReason(data.getSessionId(), data.getReason())));
 
     bus.addListener(
         NodeRemovedEvent.listener(
             nodeStatus -> {
-              batchRemoveByUri(nodeStatus.getExternalUri(), NodeRemovedEvent.class);
+              batchRemoveByUri(nodeStatus.getExternalUri(), SessionClosedReason.NODE_REMOVED);
             }));
 
     bus.addListener(
         NodeRestartedEvent.listener(
             previousNodeStatus -> {
-              batchRemoveByUri(previousNodeStatus.getExternalUri(), NodeRestartedEvent.class);
+              batchRemoveByUri(
+                  previousNodeStatus.getExternalUri(), SessionClosedReason.NODE_RESTARTED);
             }));
   }
 
@@ -116,6 +131,13 @@ public class LocalSessionMap extends SessionMap {
 
     Session session = knownSessions.get(id);
     if (session == null) {
+      // Check if this session was recently removed and provide detailed information
+      SessionRemovalInfo removalInfo = recentlyRemovedSessions.getIfPresent(id);
+      if (removalInfo != null) {
+        throw new NoSuchSessionException(
+            String.format("Unable to find session with ID: %s. Session was %s", id, removalInfo));
+      }
+
       throw new NoSuchSessionException("Unable to find session with ID: " + id);
     }
     return session;
@@ -123,10 +145,21 @@ public class LocalSessionMap extends SessionMap {
 
   @Override
   public void remove(SessionId id) {
+    removeWithReason(id, SessionClosedReason.QUIT_COMMAND);
+  }
+
+  private void removeWithReason(SessionId id, SessionClosedReason reason) {
     Require.nonNull("Session ID", id);
+    Require.nonNull("Reason", reason);
 
     Session removedSession = knownSessions.remove(id);
 
+    String reasonText = reason.getReasonText();
+    if (removedSession != null) {
+      recentlyRemovedSessions.put(id, new SessionRemovalInfo(reasonText, removedSession.getUri()));
+      LOG.fine(String.format("Tracked removal for session %s with reason: %s", id, reasonText));
+    }
+
     try (Span span = tracer.getCurrentContext().createSpan("local_sessionmap.remove")) {
       AttributeMap attributeMap = tracer.createAttributeMap();
       attributeMap.put(AttributeKey.LOGGER_CLASS.getKey(), getClass().getName());
@@ -135,15 +168,16 @@ public class LocalSessionMap extends SessionMap {
 
       String sessionDeletedMessage =
           String.format(
-              "Deleted session from local Session Map, Id: %s, Node: %s",
+              "Deleted session from local Session Map, Id: %s, Node: %s, Reason: %s",
               id,
-              removedSession != null ? String.valueOf(removedSession.getUri()) : "unidentified");
+              removedSession != null ? String.valueOf(removedSession.getUri()) : "unidentified",
+              reasonText);
       span.addEvent(sessionDeletedMessage, attributeMap);
       LOG.info(sessionDeletedMessage);
     }
   }
 
-  private void batchRemoveByUri(URI externalUri, Class<? extends Event> eventClass) {
+  private void batchRemoveByUri(URI externalUri, SessionClosedReason closeReason) {
     Set<SessionId> sessionsToRemove = knownSessions.getSessionsByUri(externalUri);
 
     if (sessionsToRemove.isEmpty()) {
@@ -152,17 +186,23 @@ public class LocalSessionMap extends SessionMap {
 
     knownSessions.batchRemove(sessionsToRemove);
 
+    // Track removal info for each session
+    for (SessionId sessionId : sessionsToRemove) {
+      recentlyRemovedSessions.put(
+          sessionId, new SessionRemovalInfo(closeReason.getReasonText(), externalUri));
+    }
+
     try (Span span = tracer.getCurrentContext().createSpan("local_sessionmap.batch_remove")) {
       AttributeMap attributeMap = tracer.createAttributeMap();
       attributeMap.put(AttributeKey.LOGGER_CLASS.getKey(), getClass().getName());
-      attributeMap.put("event.class", eventClass.getName());
+      attributeMap.put("removal.reason", closeReason.getReasonText());
       attributeMap.put("node.uri", externalUri.toString());
       attributeMap.put("sessions.count", sessionsToRemove.size());
 
       String batchRemoveMessage =
           String.format(
-              "Batch removed %d sessions from local Session Map for Node %s (triggered by %s)",
-              sessionsToRemove.size(), externalUri, eventClass.getSimpleName());
+              "Batch removed %d sessions from local Session Map for Node %s (reason: %s)",
+              sessionsToRemove.size(), externalUri, closeReason);
       span.addEvent(batchRemoveMessage, attributeMap);
       LOG.info(batchRemoveMessage);
     }
@@ -177,7 +217,7 @@ public class LocalSessionMap extends SessionMap {
       return sessions.get(id);
     }
 
-    public Session put(SessionId id, Session session) {
+    public void put(SessionId id, Session session) {
       synchronized (coordinationLock) {
         Session previous = sessions.put(id, session);
 
@@ -189,8 +229,6 @@ public class LocalSessionMap extends SessionMap {
         if (sessionUri != null) {
           sessionsByUri.computeIfAbsent(sessionUri, k -> ConcurrentHashMap.newKeySet()).add(id);
         }
-
-        return previous;
       }
     }
 
@@ -245,7 +283,8 @@ public class LocalSessionMap extends SessionMap {
 
     public Set<SessionId> getSessionsByUri(URI uri) {
       Set<SessionId> result = sessionsByUri.get(uri);
-      return (result != null && !result.isEmpty()) ? result : Set.of();
+      // Return an immutable copy to prevent concurrent modification issues
+      return (result != null && !result.isEmpty()) ? Set.copyOf(result) : Set.of();
     }
 
     public Set<Map.Entry<SessionId, Session>> entrySet() {
