@@ -22,6 +22,8 @@ import java.util.Arrays;
 import java.util.List;
 import java.util.Optional;
 import java.util.regex.Pattern;
+import org.jspecify.annotations.NullMarked;
+import org.jspecify.annotations.Nullable;
 import org.openqa.selenium.Alert;
 import org.openqa.selenium.By;
 import org.openqa.selenium.JavascriptExecutor;
@@ -34,6 +36,7 @@ import org.openqa.selenium.WebDriverException;
 import org.openqa.selenium.WebElement;
 
 /** Canned {@link ExpectedCondition}s which are generally useful within webdriver tests. */
+@NullMarked
 public class ExpectedConditions {
 
   private ExpectedConditions() {
@@ -48,7 +51,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> titleIs(final String title) {
     return new ExpectedCondition<Boolean>() {
-      private String currentTitle = "";
+      private @Nullable String currentTitle = "";
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -71,7 +74,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> titleContains(final String title) {
     return new ExpectedCondition<Boolean>() {
-      private String currentTitle = "";
+      private @Nullable String currentTitle = "";
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -94,7 +97,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> urlToBe(final String url) {
     return new ExpectedCondition<Boolean>() {
-      private String currentUrl = "";
+      private @Nullable String currentUrl = "";
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -117,7 +120,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> urlContains(final String fraction) {
     return new ExpectedCondition<Boolean>() {
-      private String currentUrl = "";
+      private @Nullable String currentUrl = "";
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -141,12 +144,12 @@ public class ExpectedConditions {
   public static ExpectedCondition<Boolean> urlMatches(final String regex) {
     return new ExpectedCondition<Boolean>() {
       private final Pattern pattern = Pattern.compile(regex);
-      private String currentUrl;
+      private @Nullable String currentUrl;
 
       @Override
       public Boolean apply(WebDriver driver) {
         currentUrl = driver.getCurrentUrl();
-        return pattern.matcher(currentUrl).find();
+        return currentUrl != null && pattern.matcher(currentUrl).find();
       }
 
       @Override
@@ -186,10 +189,11 @@ public class ExpectedConditions {
    * @param locator used to find the element
    * @return the WebElement once it is located and visible
    */
-  public static ExpectedCondition<WebElement> visibilityOfElementLocated(final By locator) {
-    return new ExpectedCondition<WebElement>() {
+  public static ExpectedCondition<@Nullable WebElement> visibilityOfElementLocated(
+      final By locator) {
+    return new ExpectedCondition<@Nullable WebElement>() {
       @Override
-      public WebElement apply(WebDriver driver) {
+      public @Nullable WebElement apply(WebDriver driver) {
         try {
           return elementIfVisible(driver.findElement(locator));
         } catch (StaleElementReferenceException | NoSuchElementException e) {
@@ -213,11 +217,11 @@ public class ExpectedConditions {
    * @param locator used to find the element
    * @return the list of WebElements once they are located
    */
-  public static ExpectedCondition<List<WebElement>> visibilityOfAllElementsLocatedBy(
+  public static ExpectedCondition<@Nullable List<WebElement>> visibilityOfAllElementsLocatedBy(
       final By locator) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       @Override
-      public List<WebElement> apply(WebDriver driver) {
+      public @Nullable List<WebElement> apply(WebDriver driver) {
         List<WebElement> elements = driver.findElements(locator);
         for (WebElement element : elements) {
           if (!element.isDisplayed()) {
@@ -242,7 +246,7 @@ public class ExpectedConditions {
    * @param elements list of WebElements
    * @return the list of WebElements once they are located
    */
-  public static ExpectedCondition<List<WebElement>> visibilityOfAllElements(
+  public static ExpectedCondition<@Nullable List<WebElement>> visibilityOfAllElements(
       final WebElement... elements) {
     return visibilityOfAllElements(Arrays.asList(elements));
   }
@@ -255,11 +259,11 @@ public class ExpectedConditions {
    * @param elements list of WebElements
    * @return the list of WebElements once they are located
    */
-  public static ExpectedCondition<List<WebElement>> visibilityOfAllElements(
+  public static ExpectedCondition<@Nullable List<WebElement>> visibilityOfAllElements(
       final List<WebElement> elements) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       @Override
-      public List<WebElement> apply(WebDriver driver) {
+      public @Nullable List<WebElement> apply(WebDriver driver) {
         for (WebElement element : elements) {
           if (!element.isDisplayed()) {
             return null;
@@ -283,10 +287,10 @@ public class ExpectedConditions {
    * @param element the WebElement
    * @return the (same) WebElement once it is visible
    */
-  public static ExpectedCondition<WebElement> visibilityOf(final WebElement element) {
-    return new ExpectedCondition<WebElement>() {
+  public static ExpectedCondition<@Nullable WebElement> visibilityOf(final WebElement element) {
+    return new ExpectedCondition<@Nullable WebElement>() {
       @Override
-      public WebElement apply(WebDriver driver) {
+      public @Nullable WebElement apply(WebDriver driver) {
         return elementIfVisible(element);
       }
 
@@ -300,7 +304,7 @@ public class ExpectedConditions {
   /**
    * @return the given element if it is visible and has non-zero size, otherwise null.
    */
-  private static WebElement elementIfVisible(WebElement element) {
+  private static @Nullable WebElement elementIfVisible(WebElement element) {
     return element.isDisplayed() ? element : null;
   }
 
@@ -310,11 +314,11 @@ public class ExpectedConditions {
    * @param locator used to find the element
    * @return the list of WebElements once they are located
    */
-  public static ExpectedCondition<List<WebElement>> presenceOfAllElementsLocatedBy(
+  public static ExpectedCondition<@Nullable List<WebElement>> presenceOfAllElementsLocatedBy(
       final By locator) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       @Override
-      public List<WebElement> apply(WebDriver driver) {
+      public @Nullable List<WebElement> apply(WebDriver driver) {
         List<WebElement> elements = driver.findElements(locator);
         return !elements.isEmpty() ? elements : null;
       }
@@ -456,11 +460,11 @@ public class ExpectedConditions {
    * @param frameLocator used to find the frame (id or name)
    * @return WebDriver instance after frame has been switched
    */
-  public static ExpectedCondition<WebDriver> frameToBeAvailableAndSwitchToIt(
+  public static ExpectedCondition<@Nullable WebDriver> frameToBeAvailableAndSwitchToIt(
       final String frameLocator) {
-    return new ExpectedCondition<WebDriver>() {
+    return new ExpectedCondition<@Nullable WebDriver>() {
       @Override
-      public WebDriver apply(WebDriver driver) {
+      public @Nullable WebDriver apply(WebDriver driver) {
         try {
           return driver.switchTo().frame(frameLocator);
         } catch (NoSuchFrameException e) {
@@ -483,10 +487,11 @@ public class ExpectedConditions {
    * @param locator used to find the frame
    * @return WebDriver instance after frame has been switched
    */
-  public static ExpectedCondition<WebDriver> frameToBeAvailableAndSwitchToIt(final By locator) {
-    return new ExpectedCondition<WebDriver>() {
+  public static ExpectedCondition<@Nullable WebDriver> frameToBeAvailableAndSwitchToIt(
+      final By locator) {
+    return new ExpectedCondition<@Nullable WebDriver>() {
       @Override
-      public WebDriver apply(WebDriver driver) {
+      public @Nullable WebDriver apply(WebDriver driver) {
         try {
           return driver.switchTo().frame(driver.findElement(locator));
         } catch (NoSuchFrameException e) {
@@ -509,11 +514,11 @@ public class ExpectedConditions {
    * @param frameLocator used to find the frame (index)
    * @return WebDriver instance after frame has been switched
    */
-  public static ExpectedCondition<WebDriver> frameToBeAvailableAndSwitchToIt(
+  public static ExpectedCondition<@Nullable WebDriver> frameToBeAvailableAndSwitchToIt(
       final int frameLocator) {
-    return new ExpectedCondition<WebDriver>() {
+    return new ExpectedCondition<@Nullable WebDriver>() {
       @Override
-      public WebDriver apply(WebDriver driver) {
+      public @Nullable WebDriver apply(WebDriver driver) {
         try {
           return driver.switchTo().frame(frameLocator);
         } catch (NoSuchFrameException e) {
@@ -536,11 +541,11 @@ public class ExpectedConditions {
    * @param frameLocator used to find the frame (webelement)
    * @return WebDriver instance after frame has been switched
    */
-  public static ExpectedCondition<WebDriver> frameToBeAvailableAndSwitchToIt(
+  public static ExpectedCondition<@Nullable WebDriver> frameToBeAvailableAndSwitchToIt(
       final WebElement frameLocator) {
-    return new ExpectedCondition<WebDriver>() {
+    return new ExpectedCondition<@Nullable WebDriver>() {
       @Override
-      public WebDriver apply(WebDriver driver) {
+      public @Nullable WebDriver apply(WebDriver driver) {
         try {
           return driver.switchTo().frame(frameLocator);
         } catch (NoSuchFrameException e) {
@@ -620,10 +625,10 @@ public class ExpectedConditions {
    * @param locator used to find the element
    * @return the WebElement once it is located and clickable (visible and enabled)
    */
-  public static ExpectedCondition<WebElement> elementToBeClickable(final By locator) {
-    return new ExpectedCondition<WebElement>() {
+  public static ExpectedCondition<@Nullable WebElement> elementToBeClickable(final By locator) {
+    return new ExpectedCondition<@Nullable WebElement>() {
       @Override
-      public WebElement apply(WebDriver driver) {
+      public @Nullable WebElement apply(WebDriver driver) {
         WebElement element = visibilityOfElementLocated(locator).apply(driver);
         try {
           if (element != null && element.isEnabled()) {
@@ -648,11 +653,12 @@ public class ExpectedConditions {
    * @param element the WebElement
    * @return the (same) WebElement once it is clickable (visible and enabled)
    */
-  public static ExpectedCondition<WebElement> elementToBeClickable(final WebElement element) {
-    return new ExpectedCondition<WebElement>() {
+  public static ExpectedCondition<@Nullable WebElement> elementToBeClickable(
+      final WebElement element) {
+    return new ExpectedCondition<@Nullable WebElement>() {
 
       @Override
-      public WebElement apply(WebDriver driver) {
+      public @Nullable WebElement apply(WebDriver driver) {
         WebElement visibleElement = visibilityOf(element).apply(driver);
         try {
           if (visibleElement != null && visibleElement.isEnabled()) {
@@ -709,10 +715,10 @@ public class ExpectedConditions {
    * @param <T> return type of the condition provided
    * @return the result of the provided condition
    */
-  public static <T> ExpectedCondition<T> refreshed(final ExpectedCondition<T> condition) {
-    return new ExpectedCondition<T>() {
+  public static <T> ExpectedCondition<@Nullable T> refreshed(final ExpectedCondition<T> condition) {
+    return new ExpectedCondition<@Nullable T>() {
       @Override
-      public T apply(WebDriver driver) {
+      public @Nullable T apply(WebDriver driver) {
         try {
           return condition.apply(driver);
         } catch (StaleElementReferenceException e) {
@@ -784,10 +790,10 @@ public class ExpectedConditions {
     };
   }
 
-  public static ExpectedCondition<Alert> alertIsPresent() {
-    return new ExpectedCondition<Alert>() {
+  public static ExpectedCondition<@Nullable Alert> alertIsPresent() {
+    return new ExpectedCondition<@Nullable Alert>() {
       @Override
-      public Alert apply(WebDriver driver) {
+      public @Nullable Alert apply(WebDriver driver) {
         try {
           return driver.switchTo().alert();
         } catch (NoAlertPresentException e) {
@@ -855,7 +861,7 @@ public class ExpectedConditions {
   public static ExpectedCondition<Boolean> attributeToBe(
       final By locator, final String attribute, final String value) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -885,7 +891,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> textToBe(final By locator, final String value) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -915,7 +921,7 @@ public class ExpectedConditions {
    */
   public static ExpectedCondition<Boolean> textMatches(final By locator, final Pattern pattern) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -944,13 +950,13 @@ public class ExpectedConditions {
    * @param number used to define minimum number of elements
    * @return Boolean true when size of elements list is more than defined
    */
-  public static ExpectedCondition<List<WebElement>> numberOfElementsToBeMoreThan(
+  public static ExpectedCondition<@Nullable List<WebElement>> numberOfElementsToBeMoreThan(
       final By locator, final Integer number) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       private Integer currentNumber = 0;
 
       @Override
-      public List<WebElement> apply(WebDriver webDriver) {
+      public @Nullable List<WebElement> apply(WebDriver webDriver) {
         List<WebElement> elements = webDriver.findElements(locator);
         currentNumber = elements.size();
         return currentNumber > number ? elements : null;
@@ -973,13 +979,13 @@ public class ExpectedConditions {
    * @param number used to define maximum number of elements
    * @return Boolean true when size of elements list is less than defined
    */
-  public static ExpectedCondition<List<WebElement>> numberOfElementsToBeLessThan(
+  public static ExpectedCondition<@Nullable List<WebElement>> numberOfElementsToBeLessThan(
       final By locator, final Integer number) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       private Integer currentNumber = 0;
 
       @Override
-      public List<WebElement> apply(WebDriver webDriver) {
+      public @Nullable List<WebElement> apply(WebDriver webDriver) {
         List<WebElement> elements = webDriver.findElements(locator);
         currentNumber = elements.size();
         return currentNumber < number ? elements : null;
@@ -1001,13 +1007,13 @@ public class ExpectedConditions {
    * @param number used to define number of elements
    * @return Boolean true when size of elements list is equal to defined
    */
-  public static ExpectedCondition<List<WebElement>> numberOfElementsToBe(
+  public static ExpectedCondition<@Nullable List<WebElement>> numberOfElementsToBe(
       final By locator, final Integer number) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
       private Integer currentNumber = 0;
 
       @Override
-      public List<WebElement> apply(WebDriver webDriver) {
+      public @Nullable List<WebElement> apply(WebDriver webDriver) {
         List<WebElement> elements = webDriver.findElements(locator);
         currentNumber = elements.size();
         return currentNumber.equals(number) ? elements : null;
@@ -1033,7 +1039,7 @@ public class ExpectedConditions {
   public static ExpectedCondition<Boolean> domPropertyToBe(
       final WebElement element, final String property, final String value) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -1060,7 +1066,7 @@ public class ExpectedConditions {
   public static ExpectedCondition<Boolean> domAttributeToBe(
       final WebElement element, final String attribute, final String value) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -1087,7 +1093,7 @@ public class ExpectedConditions {
   public static ExpectedCondition<Boolean> attributeToBe(
       final WebElement element, final String attribute, final String value) {
     return new ExpectedCondition<Boolean>() {
-      private String currentValue = null;
+      private @Nullable String currentValue = null;
 
       @Override
       public Boolean apply(WebDriver driver) {
@@ -1191,12 +1197,12 @@ public class ExpectedConditions {
    * @param childLocator used to find the ultimate child element.
    * @return visible nested element
    */
-  public static ExpectedCondition<List<WebElement>> visibilityOfNestedElementsLocatedBy(
+  public static ExpectedCondition<@Nullable List<WebElement>> visibilityOfNestedElementsLocatedBy(
       final By parent, final By childLocator) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
 
       @Override
-      public List<WebElement> apply(WebDriver driver) {
+      public @Nullable List<WebElement> apply(WebDriver driver) {
         WebElement current = driver.findElement(parent);
 
         List<WebElement> allChildren = current.findElements(childLocator);
@@ -1222,12 +1228,12 @@ public class ExpectedConditions {
    * @param childLocator used to find child element. For example td By.xpath("./tr/td")
    * @return visible sub-element
    */
-  public static ExpectedCondition<List<WebElement>> visibilityOfNestedElementsLocatedBy(
+  public static ExpectedCondition<@Nullable List<WebElement>> visibilityOfNestedElementsLocatedBy(
       final WebElement element, final By childLocator) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
 
       @Override
-      public List<WebElement> apply(WebDriver webDriver) {
+      public @Nullable List<WebElement> apply(WebDriver webDriver) {
         List<WebElement> allChildren = element.findElements(childLocator);
         // The original code only checked the visibility of the first element.
         if (!allChildren.isEmpty() && allChildren.get(0).isDisplayed()) {
@@ -1298,12 +1304,12 @@ public class ExpectedConditions {
    * @param childLocator used to find child element. For example td By.xpath("./tr/td")
    * @return sub-element
    */
-  public static ExpectedCondition<List<WebElement>> presenceOfNestedElementsLocatedBy(
+  public static ExpectedCondition<@Nullable List<WebElement>> presenceOfNestedElementsLocatedBy(
       final By parent, final By childLocator) {
-    return new ExpectedCondition<List<WebElement>>() {
+    return new ExpectedCondition<@Nullable List<WebElement>>() {
 
       @Override
-      public List<WebElement> apply(WebDriver driver) {
+      public @Nullable List<WebElement> apply(WebDriver driver) {
         List<WebElement> allChildren = driver.findElement(parent).findElements(childLocator);
 
         return allChildren.isEmpty() ? null : allChildren;
@@ -1492,10 +1498,10 @@ public class ExpectedConditions {
    * @param javaScript as executable js line
    * @return object once javaScript executes without errors
    */
-  public static ExpectedCondition<Object> jsReturnsValue(final String javaScript) {
-    return new ExpectedCondition<Object>() {
+  public static ExpectedCondition<@Nullable Object> jsReturnsValue(final String javaScript) {
+    return new ExpectedCondition<@Nullable Object>() {
       @Override
-      public Object apply(WebDriver driver) {
+      public @Nullable Object apply(WebDriver driver) {
         try {
           Object value = ((JavascriptExecutor) driver).executeScript(javaScript);
 
