@@ -17,8 +17,8 @@
 
 package org.openqa.selenium.bidi.browsingcontext;
 
-import static org.assertj.core.api.AssertionsForClassTypes.assertThat;
-import static org.assertj.core.api.AssertionsForClassTypes.assertThatExceptionOfType;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
 import static org.openqa.selenium.support.ui.ExpectedConditions.alertIsPresent;
 import static org.openqa.selenium.support.ui.ExpectedConditions.titleIs;
 import static org.openqa.selenium.support.ui.ExpectedConditions.visibilityOfElementLocated;
@@ -26,6 +26,7 @@ import static org.openqa.selenium.support.ui.ExpectedConditions.visibilityOfElem
 import java.util.List;
 import org.junit.jupiter.api.Test;
 import org.openqa.selenium.By;
+import org.openqa.selenium.Dimension;
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.Rectangle;
 import org.openqa.selenium.WebElement;
@@ -136,9 +137,9 @@ class BrowsingContextTest extends JupiterTestBase {
 
     List<BrowsingContextInfo> contextInfoList = parentWindow.getTree();
 
-    assertThat(contextInfoList.size()).isEqualTo(1);
+    assertThat(contextInfoList).hasSize(1);
     BrowsingContextInfo info = contextInfoList.get(0);
-    assertThat(info.getChildren().size()).isEqualTo(1);
+    assertThat(info.getChildren()).hasSize(1);
     assertThat(info.getId()).isEqualTo(referenceContextId);
     assertThat(info.getChildren().get(0).getUrl()).contains("formPage.html");
   }
@@ -155,7 +156,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     List<BrowsingContextInfo> contextInfoList = parentWindow.getTree(0);
 
-    assertThat(contextInfoList.size()).isEqualTo(1);
+    assertThat(contextInfoList).hasSize(1);
     BrowsingContextInfo info = contextInfoList.get(0);
     assertThat(info.getChildren()).isNull(); // since depth is 0
     assertThat(info.getId()).isEqualTo(referenceContextId);
@@ -176,7 +177,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     List<BrowsingContextInfo> contextInfoList = parentWindow.getTree(referenceContextId, 1);
 
-    assertThat(contextInfoList.size()).isEqualTo(1);
+    assertThat(contextInfoList).hasSize(1);
     BrowsingContextInfo info = contextInfoList.get(0);
     assertThat(info.getChildren()).isNotNull(); // since depth is 1
     assertThat(info.getId()).isEqualTo(referenceContextId);
@@ -199,7 +200,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     List<BrowsingContextInfo> contextInfoList = parentWindow.getTree(tab.getId());
 
-    assertThat(contextInfoList.size()).isEqualTo(1);
+    assertThat(contextInfoList).hasSize(1);
     BrowsingContextInfo info = contextInfoList.get(0);
     assertThat(info.getId()).isEqualTo(tab.getId());
     assertThat(info.getOriginalOpener()).isNull();
@@ -215,7 +216,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     List<BrowsingContextInfo> contextInfoList = window1.getTopLevelContexts();
 
-    assertThat(contextInfoList.size()).isEqualTo(2);
+    assertThat(contextInfoList).hasSize(2);
   }
 
   @Test
@@ -226,7 +227,9 @@ class BrowsingContextTest extends JupiterTestBase {
 
     window2.close();
 
-    assertThatExceptionOfType(BiDiException.class).isThrownBy(window2::getTree);
+    assertThatThrownBy(window2::getTree)
+        .isInstanceOf(BiDiException.class)
+        .hasMessageContaining("not found");
   }
 
   @Test
@@ -237,7 +240,9 @@ class BrowsingContextTest extends JupiterTestBase {
 
     tab2.close();
 
-    assertThatExceptionOfType(BiDiException.class).isThrownBy(tab2::getTree);
+    assertThatThrownBy(tab2::getTree)
+        .isInstanceOf(BiDiException.class)
+        .hasMessageContaining("not found");
   }
 
   @Test
@@ -397,7 +402,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     String screenshot = browsingContext.captureScreenshot();
 
-    assertThat(screenshot.length()).isPositive();
+    assertThat(screenshot).isNotEmpty();
   }
 
   @Test
@@ -423,7 +428,7 @@ class BrowsingContextTest extends JupiterTestBase {
                 .origin(CaptureScreenshotParameters.Origin.DOCUMENT)
                 .clipRectangle(clipRectangle));
 
-    assertThat(screenshot.length()).isPositive();
+    assertThat(screenshot).isNotEmpty();
   }
 
   @Test
@@ -440,7 +445,7 @@ class BrowsingContextTest extends JupiterTestBase {
         browsingContext.captureBoxScreenshot(
             elementRectangle.getX(), elementRectangle.getY(), 5, 5);
 
-    assertThat(screenshot.length()).isPositive();
+    assertThat(screenshot).isNotEmpty();
   }
 
   @Test
@@ -455,46 +460,41 @@ class BrowsingContextTest extends JupiterTestBase {
     String screenshot =
         browsingContext.captureElementScreenshot(((RemoteWebElement) element).getId());
 
-    assertThat(screenshot.length()).isPositive();
+    assertThat(screenshot).isNotEmpty();
   }
 
   @Test
   @NeedsFreshDriver
   void canSetViewport() {
+    Dimension initialViewportSize = getViewportSize();
+
     BrowsingContext browsingContext = new BrowsingContext(driver, driver.getWindowHandle());
     driver.get(appServer.whereIs("formPage.html"));
 
     browsingContext.setViewport(250, 300);
+    assertThat(getViewportSize()).isEqualTo(new Dimension(250, 300));
 
-    List<Long> newViewportSize =
-        (List<Long>)
-            ((JavascriptExecutor) driver)
-                .executeScript("return [window.innerWidth, window.innerHeight];");
-
-    assertThat(newViewportSize.get(0)).isEqualTo(250);
-    assertThat(newViewportSize.get(1)).isEqualTo(300);
+    browsingContext.setViewport(null, null);
+    assertThat(getViewportSize()).isEqualTo(initialViewportSize);
   }
 
   @Test
   @NeedsFreshDriver
   void canSetViewportWithDevicePixelRatio() {
+    Dimension initialViewportSize = getViewportSize();
+    double initialPixelRation = getDevicePixelRatio();
+
     BrowsingContext browsingContext = new BrowsingContext(driver, driver.getWindowHandle());
     driver.get(appServer.whereIs("formPage.html"));
 
-    browsingContext.setViewport(250, 300, 5);
+    browsingContext.setViewport(250, 300, 5.5);
 
-    List<Long> newViewportSize =
-        (List<Long>)
-            ((JavascriptExecutor) driver)
-                .executeScript("return [window.innerWidth, window.innerHeight];");
+    assertThat(getViewportSize()).isEqualTo(new Dimension(250, 300));
+    assertThat(getDevicePixelRatio()).isEqualTo(5.5);
 
-    assertThat(newViewportSize.get(0)).isEqualTo(250);
-    assertThat(newViewportSize.get(1)).isEqualTo(300);
-
-    Long newDevicePixelRatio =
-        (Long) ((JavascriptExecutor) driver).executeScript("return window.devicePixelRatio");
-
-    assertThat(newDevicePixelRatio).isEqualTo(5);
+    browsingContext.setViewport(null, null, null);
+    assertThat(getViewportSize()).isEqualTo(initialViewportSize);
+    assertThat(getDevicePixelRatio()).isEqualTo(initialPixelRation);
   }
 
   @Test
@@ -507,7 +507,7 @@ class BrowsingContextTest extends JupiterTestBase {
 
     String printPage = browsingContext.print(printOptions);
 
-    assertThat(printPage.length()).isPositive();
+    assertThat(printPage).isNotEmpty();
     // Comparing expected PDF is a hard problem.
     // As long as we are sending the parameters correctly it should be fine.
     // Trusting the browsers to do the right thing.
@@ -568,7 +568,20 @@ class BrowsingContextTest extends JupiterTestBase {
                 "<p id=\"result\"></p>"));
   }
 
+  private <T> T executeScript(String js) {
+    return (T) ((JavascriptExecutor) driver).executeScript(js);
+  }
+
   private boolean getDocumentFocus() {
-    return (boolean) ((JavascriptExecutor) driver).executeScript("return document.hasFocus();");
+    return executeScript("return document.hasFocus();");
+  }
+
+  private Dimension getViewportSize() {
+    List<Number> dimensions = executeScript("return [window.innerWidth, window.innerHeight];");
+    return new Dimension(dimensions.get(0).intValue(), dimensions.get(1).intValue());
+  }
+
+  private double getDevicePixelRatio() {
+    return ((Number) executeScript("return window.devicePixelRatio")).doubleValue();
   }
 }
