@@ -149,7 +149,7 @@ class NodeTest {
             .add(caps, new TestSessionFactory((id, c) -> new Handler(c)))
             .maximumConcurrentSessions(2);
     if (isDownloadsTestCase) {
-      builder = builder.enableManagedDownloads(true).sessionTimeout(Duration.ofSeconds(1));
+      builder = builder.enableManagedDownloads(true).sessionTimeout(ofSeconds(1));
     }
     local = builder.build();
     local2 = builder.build();
@@ -476,8 +476,8 @@ class NodeTest {
 
   @Test
   void quittingASessionShouldCauseASessionClosedEventToBeFired() {
-    AtomicReference<Object> obj = new AtomicReference<>();
-    bus.addListener(SessionClosedEvent.listener(obj::set));
+    AtomicReference<SessionId> obj = new AtomicReference<>();
+    bus.addListener(SessionClosedEvent.sessionListener(obj::set));
 
     Either<WebDriverException, CreateSessionResponse> response =
         node.newSession(createSessionRequest(caps));
@@ -488,7 +488,7 @@ class NodeTest {
     // Because we're using the event bus, we can't expect the event to fire instantly. We're using
     // an inproc bus, so in reality it's reasonable to expect the event to fire synchronously, but
     // let's play it safe.
-    Wait<AtomicReference<Object>> wait = new FluentWait<>(obj).withTimeout(ofSeconds(2));
+    Wait<AtomicReference<SessionId>> wait = new FluentWait<>(obj).withTimeout(ofSeconds(2));
     wait.until(ref -> ref.get() != null);
   }
 
@@ -568,7 +568,7 @@ class NodeTest {
     assertThat(new String(Files.readAllBytes(uploadDir.listFiles()[0].toPath()))).isEqualTo(hello);
 
     node.stop(session.getId());
-    assertThat(baseDir).doesNotExist();
+    waitUntilDirGetsDeleted(baseDir);
   }
 
   @Test
@@ -644,7 +644,7 @@ class NodeTest {
       TemporaryFilesystem downloadsTfs = local.getDownloadsFilesystem(session.getId());
       File someDir = getTemporaryFilesystemBaseDir(downloadsTfs);
       node.stop(session.getId());
-      assertThat(someDir).doesNotExist();
+      waitUntilDirGetsDeleted(someDir);
     }
   }
 
@@ -975,6 +975,10 @@ class NodeTest {
     return (List<String>) map.get("names");
   }
 
+  private void waitUntilDirGetsDeleted(File dir) {
+    new FluentWait<>(dir).withTimeout(ofSeconds(2)).until(file -> !file.exists());
+  }
+
   private static class MyClock extends Clock {
 
     private final AtomicReference<Instant> now;
