@@ -15,7 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 import warnings
-from typing import Dict, List, NoReturn, Optional, Union, overload
+from typing import NoReturn, overload
 
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.common.by import By, ByType
@@ -25,25 +25,18 @@ from selenium.webdriver.remote.webelement import WebElement
 def with_tag_name(tag_name: str) -> "RelativeBy":
     """Start searching for relative objects using a tag name.
 
-    Parameters:
-    -----------
-    tag_name : str
-        The DOM tag of element to start searching.
+    Args:
+        tag_name: The DOM tag of element to start searching.
 
     Returns:
-    --------
-    RelativeBy
-        Use this object to create filters within a `find_elements` call.
+        RelativeBy: Use this object to create filters within a `find_elements` call.
 
     Raises:
-    -------
-    WebDriverException
-        If `tag_name` is None.
+        WebDriverException: If `tag_name` is None.
 
-    Notes:
-    ------
-    - This method is deprecated and may be removed in future versions.
-    - Please use `locate_with` instead.
+    Note:
+        This method is deprecated and may be removed in future versions.
+        Please use `locate_with` instead.
     """
     warnings.warn("This method is deprecated and may be removed in future versions. Please use `locate_with` instead.")
     if not tag_name:
@@ -54,23 +47,16 @@ def with_tag_name(tag_name: str) -> "RelativeBy":
 def locate_with(by: ByType, using: str) -> "RelativeBy":
     """Start searching for relative objects your search criteria with By.
 
-    Parameters:
-    -----------
-    by : ByType
-        The method to find the element.
-
-    using : str
-        The value from `By` passed in.
+    Args:
+        by: The method to find the element.
+        using: The value from `By` passed in.
 
     Returns:
-    --------
-    RelativeBy
-        Use this object to create filters within a `find_elements` call.
+        RelativeBy: Use this object to create filters within a `find_elements` call.
 
     Example:
-    --------
-    >>> lowest = driver.find_element(By.ID, "below")
-    >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").above(lowest))
+        >>> lowest = driver.find_element(By.ID, "below")
+        >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").above(lowest))
     """
     assert by is not None, "Please pass in a by argument"
     assert using is not None, "Please pass in a using argument"
@@ -78,9 +64,9 @@ def locate_with(by: ByType, using: str) -> "RelativeBy":
 
 
 class RelativeBy:
-    """Gives the opportunity to find elements based on their relative location
-    on the page from a root element. It is recommended that you use the helper
-    function to create it.
+    """Find elements based on their relative location from a root element.
+
+    It is recommended that you use the helper function to create instances.
 
     Example:
     --------
@@ -91,46 +77,36 @@ class RelativeBy:
     >>> assert "mid" in ids
     """
 
-    LocatorType = Dict[ByType, str]
+    LocatorType = dict[ByType, str]
 
-    def __init__(self, root: Optional[Dict[ByType, str]] = None, filters: Optional[List] = None):
-        """Creates a new RelativeBy object. It is preferred if you use the
-        `locate_with` method as this signature could change.
+    def __init__(self, root: dict[ByType, str] | None = None, filters: list | None = None):
+        """Create a RelativeBy object (prefer using `locate_with` instead).
 
-        Attributes:
-        -----------
-        root : Dict[By, str]
-            - A dict with `By` enum as the key and the search query as the value
-
-        filters : List
-            - A list of the filters that will be searched. If none are passed
+        Args:
+            root: A dict with `By` enum as the key and the search query as the value
+            filters: A list of the filters that will be searched. If none are passed
                 in please use the fluent API on the object to create the filters
         """
         self.root = root
         self.filters = filters or []
 
     @overload
-    def above(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def above(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def above(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def above(self, element_or_locator: Union[WebElement, LocatorType, None] = None) -> "RelativeBy":
+    def above(self, element_or_locator: WebElement | LocatorType | None = None) -> "RelativeBy":
         """Add a filter to look for elements above.
 
-        Parameters:
-        -----------
-        element_or_locator : Union[WebElement, Dict, None]
-            Element to look above
+        Args:
+            element_or_locator: Element to look above
 
         Returns:
-        --------
-        RelativeBy
+            RelativeBy
 
         Raises:
-        -------
-        WebDriverException
-            If `element_or_locator` is None.
+            WebDriverException: If `element_or_locator` is None.
 
         Example:
         --------
@@ -144,32 +120,26 @@ class RelativeBy:
         return self
 
     @overload
-    def below(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def below(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def below(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def below(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def below(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements below.
 
-        Parameters:
-        -----------
-        element_or_locator : Union[WebElement, Dict, None]
-            Element to look below
+        Args:
+            element_or_locator: Element to look below
 
         Returns:
-        --------
-        RelativeBy
+            RelativeBy
 
         Raises:
-        -------
-        WebDriverException
-            If `element_or_locator` is None.
+            WebDriverException: If `element_or_locator` is None.
 
         Example:
-        --------
-        >>> highest = driver.find_element(By.ID, "high")
-        >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").below(highest))
+            >>> highest = driver.find_element(By.ID, "high")
+            >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").below(highest))
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling below method")
@@ -178,32 +148,26 @@ class RelativeBy:
         return self
 
     @overload
-    def to_left_of(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def to_left_of(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def to_left_of(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def to_left_of(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def to_left_of(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements to the left of.
 
-        Parameters:
-        -----------
-        element_or_locator : Union[WebElement, Dict, None]
-            Element to look to the left of
+        Args:
+            element_or_locator: Element to look to the left of
 
         Returns:
-        --------
-        RelativeBy
+            RelativeBy
 
         Raises:
-        -------
-        WebDriverException
-            If `element_or_locator` is None.
+            WebDriverException: If `element_or_locator` is None.
 
         Example:
-        --------
-        >>> right = driver.find_element(By.ID, "right")
-        >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").to_left_of(right))
+            >>> right = driver.find_element(By.ID, "right")
+            >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").to_left_of(right))
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling to_left_of method")
@@ -212,32 +176,26 @@ class RelativeBy:
         return self
 
     @overload
-    def to_right_of(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def to_right_of(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def to_right_of(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def to_right_of(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def to_right_of(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements right of.
 
-        Parameters:
-        -----------
-        element_or_locator : Union[WebElement, Dict, None]
-            Element to look right of
+        Args:
+            element_or_locator: Element to look right of
 
         Returns:
-        --------
-        RelativeBy
+            RelativeBy
 
         Raises:
-        -------
-        WebDriverException
-            If `element_or_locator` is None.
+            WebDriverException: If `element_or_locator` is None.
 
         Example:
-        --------
-        >>> left = driver.find_element(By.ID, "left")
-        >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").to_right_of(left))
+            >>> left = driver.find_element(By.ID, "left")
+            >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").to_right_of(left))
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling to_right_of method")
@@ -246,16 +204,16 @@ class RelativeBy:
         return self
 
     @overload
-    def straight_above(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def straight_above(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def straight_above(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def straight_above(self, element_or_locator: Union[WebElement, LocatorType, None] = None) -> "RelativeBy":
+    def straight_above(self, element_or_locator: WebElement | LocatorType | None = None) -> "RelativeBy":
         """Add a filter to look for elements above.
 
-        :Args:
-            - element_or_locator: Element to look above
+        Args:
+            element_or_locator: Element to look above
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling above method")
@@ -264,16 +222,16 @@ class RelativeBy:
         return self
 
     @overload
-    def straight_below(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def straight_below(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def straight_below(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def straight_below(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def straight_below(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements below.
 
-        :Args:
-            - element_or_locator: Element to look below
+        Args:
+            element_or_locator: Element to look below
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling below method")
@@ -282,16 +240,16 @@ class RelativeBy:
         return self
 
     @overload
-    def straight_left_of(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def straight_left_of(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def straight_left_of(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def straight_left_of(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def straight_left_of(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements to the left of.
 
-        :Args:
-            - element_or_locator: Element to look to the left of
+        Args:
+            element_or_locator: Element to look to the left of
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling to_left_of method")
@@ -300,16 +258,16 @@ class RelativeBy:
         return self
 
     @overload
-    def straight_right_of(self, element_or_locator: Union[WebElement, LocatorType]) -> "RelativeBy": ...
+    def straight_right_of(self, element_or_locator: WebElement | LocatorType) -> "RelativeBy": ...
 
     @overload
     def straight_right_of(self, element_or_locator: None = None) -> "NoReturn": ...
 
-    def straight_right_of(self, element_or_locator: Union[WebElement, Dict, None] = None) -> "RelativeBy":
+    def straight_right_of(self, element_or_locator: WebElement | dict | None = None) -> "RelativeBy":
         """Add a filter to look for elements right of.
 
-        :Args:
-            - element_or_locator: Element to look right of
+        Args:
+            element_or_locator: Element to look right of
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling to_right_of method")
@@ -318,36 +276,28 @@ class RelativeBy:
         return self
 
     @overload
-    def near(self, element_or_locator: Union[WebElement, LocatorType], distance: int = 50) -> "RelativeBy": ...
+    def near(self, element_or_locator: WebElement | LocatorType, distance: int = 50) -> "RelativeBy": ...
 
     @overload
     def near(self, element_or_locator: None = None, distance: int = 50) -> "NoReturn": ...
 
-    def near(self, element_or_locator: Union[WebElement, LocatorType, None] = None, distance: int = 50) -> "RelativeBy":
+    def near(self, element_or_locator: WebElement | LocatorType | None = None, distance: int = 50) -> "RelativeBy":
         """Add a filter to look for elements near.
 
-        Parameters:
-        -----------
-        element_or_locator : Union[WebElement, Dict, None]
-            Element to look near by the element or within a distance
-
-        distance : int
-            Distance in pixel
+        Args:
+            element_or_locator: Element to look near by the element or within a distance
+            distance: Distance in pixel
 
         Returns:
-        --------
-        RelativeBy
+            RelativeBy
 
         Raises:
-        -------
-        WebDriverException
-            - If `element_or_locator` is None
-            - If `distance` is less than or equal to 0.
+            WebDriverException: If `element_or_locator` is None
+            WebDriverException: If `distance` is less than or equal to 0.
 
         Example:
-        --------
-        >>> near = driver.find_element(By.ID, "near")
-        >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").near(near, 50))
+            >>> near = driver.find_element(By.ID, "near")
+            >>> elements = driver.find_elements(locate_with(By.CSS_SELECTOR, "p").near(near, 50))
         """
         if not element_or_locator:
             raise WebDriverException("Element or locator must be given when calling near method")
@@ -357,9 +307,8 @@ class RelativeBy:
         self.filters.append({"kind": "near", "args": [element_or_locator, distance]})
         return self
 
-    def to_dict(self) -> Dict:
-        """Create a dict that will be passed to the driver to start searching
-        for the element."""
+    def to_dict(self) -> dict:
+        """Create a dict to be passed to the driver for element searching."""
         return {
             "relative": {
                 "root": self.root,
