@@ -570,7 +570,7 @@ def test_proxy_auth_with_special_characters_url_encoded():
     conn = remote_connection._get_connection_manager()
     assert isinstance(conn, ProxyManager)
 
-    expected_auth = base64.b64encode("user:passw#rd".encode()).decode()  # Decoded password
+    expected_auth = base64.b64encode(b"user:passw#rd").decode()  # Decoded password
     expected_headers = make_headers(proxy_basic_auth="user:passw#rd")  # Unquoted password
 
     assert conn.proxy_headers == expected_headers
